@@ -1,5 +1,5 @@
 --[[
-CodeBlock filter – Convert a Div block into a CodeBlock
+Table filter – Adds Table Numbering (ignores widetables)
 License:   MIT – see LICENSE file for details
 adapted from: Albert Krewinkel implementation
 original License: CC0
@@ -7,6 +7,8 @@ original License: CC0
 
 -- Table counter variable
 tables = 0
+
+
 --[[
 Applies the filter to table elements
 --]]
@@ -19,15 +21,26 @@ function Table(el)
     if not caption[1] then
       -- Table has no caption, just add the label
       caption = pandoc.Blocks{label}
+      if (pandoc.utils.stringify(el.caption.long) == "") then
+          print("widetable")
+          tables = tables - 1
+          caption[1].content = pandoc.Space()
+      end
     elseif caption[1].tag == 'Plain' or caption[1].tag == 'Para' then
-      -- Prepend label to paragraph
-      label:extend{pandoc.Str ':', pandoc.Space()}
-      caption[1].content = label .. caption[1].content
+      -- skip numbering widetables
+      if pandoc.utils.stringify(caption[1].content) == "widetable" then
+          --print("widetable")
+          tables = tables - 1
+        caption[1].content = pandoc.Space()
+      else
+         -- Prepend label to paragraph
+         label:extend{pandoc.Str ':', pandoc.Space()}
+        caption[1].content = label .. caption[1].content
+      end
     else
       -- Add label as plain block element
-      label:extend{pandoc.Str ':', pandoc.Space()}
-      caption:insert(1, pandoc.Plain(label))
     end
     el.caption.long = caption
     return el
 end
+
